@@ -1,12 +1,10 @@
 """
 Module for calculating doubly logistic approximation.
 
-Credits:
-Copyright (c) 2020 Beno Šircelj (Josef Stefan Institute)
-Copyright (c) 2017-2022 Matej Aleksandrov, Žiga Lukšič (Sinergise)
+Copyright (c) 2017- Sinergise and contributors
+For the full list of contributors, see the CREDITS file in the root directory of this source tree.
 
-This source code is licensed under the MIT license found in the LICENSE
-file in the root directory of this source tree.
+This source code is licensed under the MIT license, see the LICENSE file in the root directory of this source tree.
 """
 from __future__ import annotations
 
@@ -20,7 +18,7 @@ from eolearn.core import EOPatch, EOTask, FeatureType
 from eolearn.core.types import SingleFeatureSpec
 
 
-def doubly_logistic(middle, initial_value, scale, a1, a2, a3, a4, a5) -> np.ndarray:
+def doubly_logistic(middle, initial_value, scale, a1, a2, a3, a4, a5) -> np.ndarray:  # type: ignore[no-untyped-def]
     # pylint: disable=invalid-name
     """Function passed to `scipy.optimize`"""
     funclist = [lambda y: np.exp(-(((a1 - y) / a4) ** a5)), lambda y: np.exp(-(((y - a1) / a2) ** a3))]
@@ -95,7 +93,7 @@ class DoublyLogisticApproximationTask(EOTask):
         """
         data = eopatch[self.feature].squeeze(axis=3)
 
-        times = np.asarray([time.toordinal() for time in eopatch.timestamp])
+        times = np.asarray([time.toordinal() for time in eopatch.timestamps])
         times = (times - times[0]) / (times[-1] - times[0])
 
         time, height, width = data.shape
