@@ -1,21 +1,21 @@
 """
 Utilities for EOPatch feature modification
 
-Credits:
-Copyright (c) 2017-2022 Matej Aleksandrov, Žiga Lukšič (Sinergise)
+Copyright (c) 2017- Sinergise and contributors
+For the full list of contributors, see the CREDITS file in the root directory of this source tree.
 
-This source code is licensed under the MIT license found in the LICENSE
-file in the root directory of this source tree.
+This source code is licensed under the MIT license, see the LICENSE file in the root directory of this source tree.
 """
 import warnings
 from enum import Enum
 from functools import partial
-from typing import Callable, Dict, Optional, Tuple, Union
+from typing import Dict, Optional, Tuple, Union
 
 import numpy as np
 from PIL import Image
 
 from eolearn.core.exceptions import EORuntimeWarning
+from eolearn.core.utils.common import _apply_to_spatial_axes
 
 _CV2_IMPORT_MESSAGE = "The CV2 backend is not installed by default. We suggest you install the `opencv-python` package."
 
@@ -171,27 +171,3 @@ def spatially_resize_image(
 
 def _pil_resize_ndarray(image: np.ndarray, size: Tuple[int, int], method: Image.Resampling) -> np.ndarray:
     return np.array(Image.fromarray(image).resize(size, method))
-
-
-def _apply_to_spatial_axes(
-    resize_function: Callable[[np.ndarray], np.ndarray], data: np.ndarray, spatial_axes: Tuple[int, int]
-) -> np.ndarray:
-    """Helper function for applying resizing to spatial axes
-
-    Recursively slices data into smaller-dimensional ones, until only the spatial axes remain. The indices of spatial
-    axes have to be adjusted if the recursion-axis is smaller than either one, e.g. spatial axes (1, 2) become (0, 1)
-    after splitting the 3D data along axis 0 into 2D arrays.
-
-    After achieving 2D data slices the resizing function is applied. The data is then reconstructed into original form.
-    """
-
-    if data.ndim <= 2:
-        return resize_function(data)
-
-    axis = next(i for i in range(data.ndim) if i not in spatial_axes)
-    data = np.moveaxis(data, axis, 0)
-
-    ax1, ax2 = (ax if axis > ax else ax - 1 for ax in spatial_axes)
-
-    mapped_slices = [_apply_to_spatial_axes(resize_function, data_slice, (ax1, ax2)) for data_slice in data]
-    return np.moveaxis(np.stack(mapped_slices), 0, axis)
